Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(972)

Unified Diff: third_party/WebKit/Source/platform/WebFrameScheduler.h

Issue 2620743002: Don't throttle web views until they've been in the background for 10s (Closed)
Patch Set: Fix asan test issue Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/WebFrameScheduler.h
diff --git a/third_party/WebKit/Source/platform/WebFrameScheduler.h b/third_party/WebKit/Source/platform/WebFrameScheduler.h
index 899d78e630d223cf4b8175492253df6bdad2cbe2..069fedf6b2bbc6dd2eac8d1e6ed62e3edc2c383f 100644
--- a/third_party/WebKit/Source/platform/WebFrameScheduler.h
+++ b/third_party/WebKit/Source/platform/WebFrameScheduler.h
@@ -19,10 +19,9 @@ class WebFrameScheduler {
// The scheduler may throttle tasks associated with offscreen frames.
virtual void setFrameVisible(bool) {}
- // Tells the scheduler that the page this frame belongs to is not visible.
- // The scheduler may throttle tasks associated with pages that are not
- // visible.
- virtual void setPageVisible(bool) {}
+ // Tells the scheduler that the page this frame belongs to supposed to be
+ // throttled (because it's not been visible for a few seconds).
+ virtual void setPageThrottled(bool) {}
// Set whether this frame is suspended. Only unthrottledTaskRunner tasks are
// allowed to run on a suspended frame.

Powered by Google App Engine
This is Rietveld 408576698